==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/PositiveVolumeIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PositiveVolumeIndexIndicatorDescription } from "./PositiveVolumeIndexIndicatorDescription";
/**
 * @hidden
 */
export let PositiveVolumeIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PositiveVolumeIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PositiveVolumeIndexIndicatorDescriptionMetadata.a == null) {
                PositiveVolumeIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PositiveVolumeIndexIndicatorDescriptionMetadata.c(PositiveVolumeIndexIndicatorDescriptionMetadata.a);
            }
            if (a.j(PositiveVolumeIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.y(PositiveVolumeIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            PositiveVolumeIndexIndicatorDescriptionMetadata.b(a);
            a.aa("PositiveVolumeIndexIndicator", () => new PositiveVolumeIndexIndicatorDescription());
            a.z("PositiveVolumeIndexIndicator", PositiveVolumeIndexIndicatorDescriptionMetadata.a);
        }
    }
    PositiveVolumeIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PositiveVolumeIndexIndicatorDescriptionMetadata, 'PositiveVolumeIndexIndicatorDescriptionMetadata');
    PositiveVolumeIndexIndicatorDescriptionMetadata.a = null;
    return PositiveVolumeIndexIndicatorDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PositiveVolumeIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PositiveVolumeIndexIndicatorDescription } from "./PositiveVolumeIndexIndicatorDescription";
/**
 * @hidden
 */
export let PositiveVolumeIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class PositiveVolumeIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (PositiveVolumeIndexIndicatorDescriptionMetadata.a == null) {
                PositiveVolumeIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PositiveVolumeIndexIndicatorDescriptionMetadata.c(PositiveVolumeIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(PositiveVolumeIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.aa(PositiveVolumeIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            PositiveVolumeIndexIndicatorDescriptionMetadata.b(a);
            a.ac("PositiveVolumeIndexIndicator", () => new PositiveVolumeIndexIndicatorDescription());
            a.ab("PositiveVolumeIndexIndicator", PositiveVolumeIndexIndicatorDescriptionMetadata.a);
        }
    }
    PositiveVolumeIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(PositiveVolumeIndexIndicatorDescriptionMetadata, 'PositiveVolumeIndexIndicatorDescriptionMetadata');
    PositiveVolumeIndexIndicatorDescriptionMetadata.a = null;
    return PositiveVolumeIndexIndicatorDescriptionMetadata;
})();
